==> fluidsynth_2.1.1.orig.tar.gz: fluidsynth-2.1.1/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

<!-- DO NOT SUBMIT SUPPORT REQUESTS OR "HOW TO" QUESTIONS HERE!
Else it might be closed without further notice.

If you have a question look into our wiki
( https://github.com/FluidSynth/fluidsynth/wiki )
or the developer resources
( http://www.fluidsynth.org/api/ )

If you still have a question, need support or want to discuss ideas, contact our mailing list:
https://lists.nongnu.org/mailman/listinfo/fluid-dev

Below is a form that shall help getting relevant information for bugs together.
We strongly recommend to use it! Feel free to edit or remove inapplicable/unneeded parts.
-->

### FluidSynth version
_Execute `fluidsynth --version` and provide the output._

### Describe the bug
_Provide a clear and concise description of the current situation, e.g. how the bug manifests._

### Expected behavior
_Provide a clear and concise description of what you expected to happen._

### Steps to reproduce
_Please explain the steps required to duplicate the issue, esp. if you are able to provide a sample application. E.g. how to start fluidsynth, what shell commands to enter, what midi events to send, etc._

### Additional context
_If you are able to illustrate the bug with an example, please provide simple
source code below or as attached file. List any other information that is relevant to your issue, e.g. stack traces, related issues, build logs, suggestions on how to fix, links to related discussions at fluid-dev, etc._

```
insert code snippets, soundfonts or anything relevant here, or attach it as extra file(s) if it's too much
```

==> fluidsynth_2.3.4.orig.tar.gz: fluidsynth-2.3.4/.github/ISSUE_TEMPLATE/bug_report.md <==
---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

<!-- DO NOT SUBMIT SUPPORT REQUESTS OR "HOW TO" QUESTIONS HERE!
Else it might be closed without further notice.

If you have a question look into our wiki
( https://github.com/FluidSynth/fluidsynth/wiki )
or the developer resources
( https://www.fluidsynth.org/api/ )

If you still have a question, need support or want to discuss ideas, contact our mailing list
https://lists.nongnu.org/mailman/listinfo/fluid-dev

or start a GitHub Discussion:
https://github.com/FluidSynth/fluidsynth/discussions

Below is a form that shall help getting relevant information for bugs together.
We strongly recommend to use it! Feel free to edit or remove inapplicable/unneeded parts.
-->

### FluidSynth version
_Execute `fluidsynth --version` and provide the output._

### Describe the bug
_Provide a clear and concise description of the current situation, e.g. how the bug manifests._

### Expected behavior
_Provide a clear and concise description of what you expected to happen._

### Steps to reproduce
_Please explain the steps required to duplicate the issue, esp. if you are able to provide a sample application. E.g. how to start fluidsynth, what shell commands to enter, what midi events to send, etc._

### Additional context
_If you are able to illustrate the bug with an example, please provide simple
source code below or as attached file. List any other information that is relevant to your issue, e.g. stack traces, related issues, build logs, suggestions on how to fix, links to related discussions at fluid-dev, etc._

```
insert code snippets, soundfonts or anything relevant here, or attach it as extra file(s) if it's too much
```
